package com.dayou.service.impl;

import com.dayou.dto.AssetsSelectDTO;
import com.dayou.dto.WorkNodeCommit;
import com.dayou.entity.Assets;
import com.dayou.enums.MainBusinessEnum;
import com.dayou.mapper.AssetsMapper;
import com.dayou.service.IAssetsService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.dayou.service.IBusinessNumberService;
import com.dayou.service.workflow.IWorkFlowService;
import com.dayou.vo.AssetsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.dayou.utils.ExcelUtil;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import org.springframework.web.multipart.MultipartFile;
import java.util.List;
import java.util.ArrayList;
import org.springframework.transaction.annotation.Transactional;
import com.dayou.enums.BatchTaskTypeEnum;

/**
 * <p>
 * 资产业务订单表 服务实现类
 * </p>
 *
 * @author GouGengquan
 * @since 2024-03-28
 */
@Service
public class AssetsServiceImpl extends ServiceImpl<AssetsMapper, Assets> implements IAssetsService {

    @Autowired
    private IBusinessNumberService businessNumberService;

    @Autowired
    private IWorkFlowService workFlowService;

    @Autowired
    private AssetsMapper assetsMapper;

    /**
     * 条件查询资产任务列表
     * @param page 分页条件
     * @param assetsSelectDTO 查询条件
     * @return Page<AssetsVO>
     */
    @Override
    public Page<AssetsVO> selectPage(Page page, AssetsSelectDTO assetsSelectDTO){
        return assetsMapper.selectPage(page, assetsSelectDTO);
    }


    @Override
    public Assets detail(Long id){
        return this.getById(id);
    }

    /**
     * 新增资产业务订单
     * @param assets 资产订单信息
     * @return Boolean
     */
    @Override
    public WorkNodeCommit add(Assets assets){
        //获取项目编号
        assets.setOrderId(businessNumberService.takeOrderNumber());
        //新增订单信息
        this.save(assets);
        //发起流程
        return workFlowService.openingOrder(MainBusinessEnum.ASSET_BUSINESS,assets.getId(),assets.getOrderId(),assets.getRemark());
    }

    @Override
    public Boolean update(Assets assets){
        return  this.updateById(assets);
    }

    @Override
    public Boolean delete(Long id){
        //逻辑删除
        return this.removeById(id);
    }
}
